pub enum MetricLabel {
Static(String),
Label(String),
KeyOnly(String, String),
CategoryOnly(String, String),
KeyAndCategory(String, String),
}Expand description
The type of dynamic label applied to a base metric. Used to help identify the necessary validation to be performed.
Variants
Static(String)
Static Label – no validation required
Label(String)
A dynamic label applied from a LabeledMetric
KeyOnly(String, String)
A label applied by a DualLabeledCounter that contains a dynamic key and static category
CategoryOnly(String, String)
A label applied by a DualLabeledCounter that contains a static key and dynamic category
KeyAndCategory(String, String)
A label applied by a DualLabeledCounter that contains a dynamic key and category