Event

Trait Event 

pub trait Event: TestGetValue<Output = Vec<RecordedEvent>> {
    type Extra: ExtraKeys;

    // Required method
    fn record<M: Into<Option<Self::Extra>>>(&self, extra: M);
}
A description for the EventMetric type.

When changing this trait, make sure all the operations are implemented in the related type in ../metrics/.

Required Associated Types

type Extra: ExtraKeys

The type of the allowed extra keys for this event.

Required Methods

fn record<M: Into<Option<Self::Extra>>>(&self, extra: M)

Records an event.

Arguments
  • extra - (optional) An object for the extra keys.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors