pub struct RemoteSettingsConfig {
pub metrics_enabled: HashMap<String, bool>,
pub pings_enabled: HashMap<String, bool>,
pub event_threshold: Option<u32>,
pub session_sample_rate: Option<f64>,
}Expand description
Represents a list of metrics and an associated boolean property indicating if the metric is enabled from the remote-settings configuration store.
The expected format of this data is stringified JSON in the following format:
{
"category.metric_name": true
}Fields
metrics_enabled: HashMap<String, bool>This is a HashMap consisting of base_identifiers as keys
and bool values representing an override for the disabled
property of the metric, only inverted to reduce confusion.
If a particular metric has a value of true here, it means
the default of the metric will be overriden and set to the
enabled state.
pings_enabled: HashMap<String, bool>This is a HashMap consisting of ping names as keys and
boolean values representing on override for the default
enabled state of the ping of the same name.
event_threshold: Option<u32>The threshold of events that will be buffered before an events ping is collected and submitted. It overrides the value configured at initialization time.
session_sample_rate: Option<f64>Remote override for the session sampling rate (0.0–1.0). When set, this overrides the value configured at initialization time. Changes take effect at the next session start.
Implementations