Text

Trait Text 

pub trait Text: TestGetValue<Output = String> {
    // Required methods
    fn set<S: Into<String>>(&self, value: S);
    fn test_get_num_recorded_errors(&self, error: ErrorType) -> i32;
}
A description for the TextMetric type.

When changing this trait, make sure all the operations are implemented in the related type in ../metrics/.

Required Methods

fn set<S: Into<String>>(&self, value: S)

Sets to the specified value.

Arguments
  • value - The string to set the metric to.
Notes

Truncates the value if it is longer than MAX_LENGTH_VALUE bytes and logs an error.

fn test_get_num_recorded_errors(&self, error: ErrorType) -> i32

Exported for test purposes.

Gets the number of recorded errors for the given metric and error type.

Arguments
  • error - The type of error
Returns

The number of errors reported.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors